@@ -1,17 +1,20 @@
 import shelve
 import xmltodict
 import time
-
 from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
 from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
+
 global count_host_ids_added_to_shelve
 global host_list_shelve_database
 global host_list_xml_files_selected
+global counter_obj
 
 
 def transform_host_list_item_to_shelve(_, item):
     global host_list_shelve_database
     global count_host_ids_added_to_shelve
+    global counter_obj
+
     if len(_) > 2 and "HOST" != _[3][0]:
         return True
     ID = item['ID']
@@ -20,7 +23,8 @@ def transform_host_list_item_to_shelve(_, item):
     for i in range(5):
         try:
             host_list_shelve_database[ID] = item
-            count_host_ids_added_to_shelve = count_host_ids_added_to_shelve + 1
+            count_host_ids_added_to_shelve += 1
+            counter_obj.display_counter_to_log()
             break
         except Exception as e:
             time.sleep(1)
@@ -40,21 +44,25 @@ def host_list_shelve():
     global count_host_ids_added_to_shelve
     global host_list_shelve_database
     global host_list_xml_files_selected
+    global counter_obj
+
     count_host_ids_added_to_shelve = 0
+    counter_obj = \
+        etld_lib_functions.DisplayCounterToLog(display_counter_at=10000,
+                                               logger_func=etld_lib_functions.logger.info,
+                                               display_counter_log_message="count host list records written to shelve")
+
     # xml_files, other = (not ec2, google or azure). (ec2,google,azure = include metadata for each)
-    if etld_lib_config.host_list_payload_option == 'notags': # Process other with basic query options.
-        host_list_xml_files_selected = {'host_list_other_xml_file': etld_lib_config.host_list_other_xml_file}
-    else:
-        host_list_xml_files_selected = {'host_list_other_xml_file': etld_lib_config.host_list_other_xml_file,
-                                        'host_list_ec2_xml_file': etld_lib_config.host_list_ec2_xml_file,
-                                        'host_list_gcp_xml_file': etld_lib_config.host_list_gcp_xml_file,
-                                        'host_list_azure_xml_file': etld_lib_config.host_list_azure_xml_file}
+    host_list_xml_files_selected = {'host_list_other_xml_file': etld_lib_config.host_list_other_xml_file}
     etld_lib_functions.log_dbm_info(etld_lib_config.host_list_shelve_file)
+    # TODO add ability to process over 1 million hosts
+    host_list_xml_file = host_list_xml_files_selected['host_list_other_xml_file']
     try:
         for host_list_xml_file in host_list_xml_files_selected.values():
             with open(host_list_xml_file, 'r', encoding='utf-8') as xml_file:
                 with shelve.open(str(etld_lib_config.host_list_shelve_file), flag='n') as host_list_shelve_database:
                     xmltodict.parse(xml_file.read(), item_depth=4, item_callback=transform_host_list_item_to_shelve)
+        counter_obj.display_final_counter_to_log()
     except Exception as e:
         etld_lib_functions.logger.error(f"XML File corruption detected: {host_list_xml_file}")
         etld_lib_functions.logger.error(f"Exception: {e}")
@@ -65,7 +73,7 @@ def end_msg_host_list_shelve():
     global count_host_ids_added_to_shelve
     global host_list_xml_files_selected
     etld_lib_functions.logger.info(
-        f"count host ids added to shelve: {count_host_ids_added_to_shelve:,} for {str(etld_lib_config.host_list_shelve_file)}")
+        f"total count host list shelve records written: {count_host_ids_added_to_shelve:,} for {str(etld_lib_config.host_list_shelve_file)}")
     for host_list_xml_file in host_list_xml_files_selected.values():
         etld_lib_functions.log_file_info(host_list_xml_file, 'in')
     etld_lib_functions.log_dbm_info(etld_lib_config.host_list_shelve_file)
