@@ -2,10 +2,13 @@ import csv
 import shelve
 from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
 from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
+import dbm.gnu
+import pickle
+import json
 global count_host_ids_written
 
 
-def prepare_csv_cell(csv_cell, csv_column):
+def prepare_csv_cell(csv_cell, csv_column, present_csv_cell_as_json=False):
     if csv_cell is None:
         csv_cell = ""
     elif 'DATE' in csv_column:  # Prepare dates for use in Excel or Database
@@ -13,10 +16,13 @@ def prepare_csv_cell(csv_cell, csv_column):
     elif 'ASSET_GROUP_IDS' in csv_column:  # Prepare IDS for use in Excel
         csv_cell = csv_cell.replace(",", "\n")
     elif not isinstance(csv_cell, str):  # Flatten Nested XML into String
-        flatten = etld_lib_functions.flatten_nest(csv_cell)
-        csv_cell = ""
-        for key in flatten.keys():
-            csv_cell = f"{csv_cell}{key}:{flatten[key]}\n"
+        if present_csv_cell_as_json:
+            csv_cell = json.dumps(csv_cell)
+        else:
+            flatten = etld_lib_functions.flatten_nest(csv_cell)
+            csv_cell = ""
+            for key in flatten.keys():
+                csv_cell = f"{csv_cell}{key}:{flatten[key]}\n"
     return csv_cell
 
 
@@ -25,6 +31,10 @@ def host_list_to_csv():  # Create CSV File from Shelve Database
     host_list_csv_file = etld_lib_config.host_list_csv_file     # Output CSV File
     csv_columns = etld_lib_functions.host_list_csv_columns()         # Host List Columns
     count_host_ids_written = 0
+    counter_obj = \
+        etld_lib_functions.DisplayCounterToLog(display_counter_at=10000,
+                                               logger_func=etld_lib_functions.logger.info,
+                                               display_counter_log_message="count host list records written to csv")
     csv_headers = {}
     for header in csv_columns:
         csv_headers[header] = ""
@@ -34,14 +44,18 @@ def host_list_to_csv():  # Create CSV File from Shelve Database
             writer.writeheader()
             csv_row = csv_headers.copy()
             # Iterate through Shelve Database
-            with shelve.open(str(etld_lib_config.host_list_shelve_file), flag='r') as shelve_database:  # Open Host List Shelve DB
-                for shelve_database_item in shelve_database:
-                    host_list_item = shelve_database[shelve_database_item]
+            #with shelve.open(str(etld_lib_config.host_list_shelve_file), flag='r') as shelve_database:  # Open Host List Shelve DB
+            with dbm.gnu.open(str(etld_lib_config.host_list_shelve_file), 'rf') as shelve_database:
+                shelve_database_item = shelve_database.firstkey()
+                while shelve_database_item is not None:
+                #for shelve_database_item in shelve_database:
+                    host_list_item = pickle.loads(shelve_database[shelve_database_item])
+                    # host_list_item = shelve_database[shelve_database_item]
                     for csv_column in csv_columns:  # Iterate through expected columns (contract)
                         if csv_column in host_list_item.keys():  # Iterate through columns found in Shelve
                             host_list_item[csv_column] = prepare_csv_cell(
-                                                         host_list_item[csv_column], csv_column)
-                            # TODO add truncated field list to data.  low priority.
+                                                         host_list_item[csv_column], csv_column,
+                                                         etld_lib_config.host_list_present_csv_cell_as_json)
                             truncated_field_list = ""
                             csv_row[csv_column], truncated_field_list = \
                                 etld_lib_functions.truncate_csv_cell(
@@ -53,9 +67,11 @@ def host_list_to_csv():  # Create CSV File from Shelve Database
                             csv_row[csv_column] = ""  # Ensure blank is added to each required empty field
                     # Write CSV row, Prepare for next row.
                     writer.writerow(csv_row)
-                    count_host_ids_written = count_host_ids_written + 1
+                    count_host_ids_written += 1
+                    counter_obj.display_counter_to_log()
                     csv_row = csv_headers.copy()
-
+                    shelve_database_item = shelve_database.nextkey(shelve_database_item)
+        counter_obj.display_final_counter_to_log()
     except Exception as e:
         etld_lib_functions.logger.error(f"Error in File: {__file__} Line: {etld_lib_functions.lineno()}")
         etld_lib_functions.logger.error(f"Error writing to file: {str(host_list_csv_file)}, please retry after fixing error")
@@ -69,7 +85,6 @@ def start_msg_host_list_csv():
 
 def end_msg_host_list_csv():
     global count_host_ids_written
-    etld_lib_functions.logger.info(f"count hosts written to csv: {count_host_ids_written:,}")
     etld_lib_functions.log_file_info(etld_lib_config.host_list_shelve_file, 'in')
     etld_lib_functions.log_dbm_info(etld_lib_config.host_list_shelve_file)
     etld_lib_functions.log_file_info(etld_lib_config.host_list_csv_file)
