@@ -15,7 +15,7 @@ def host_list_sqlite():
     etld_lib_sqlite_tables.bulk_insert_csv_file(etld_lib_config.host_list_table_name,
                                                 etld_lib_config.host_list_csv_file,
                                                 etld_lib_functions.host_list_csv_columns(),
-                                                host_list_sqlite_file)
+                                                host_list_sqlite_file, "host list")
 
 
 def start_msg_host_list_sqlite():
