@@ -1,6 +1,7 @@
 import csv
 import shelve
 import time
+import json
 from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
 from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
 
@@ -8,18 +9,26 @@ global kb_cve_qid_list # Holds csv-> qid dictionary
 global count_qids_written_to_shelve
 
 
-def prepare_csv_cell(csv_cell, csv_column, qid):
+def prepare_csv_cell(csv_cell, csv_column, qid, present_csv_cell_as_json=False):
+    discarded_data = ""
     if csv_cell is None:
         csv_cell = ""
     elif 'DATETIME' in csv_column:  # Prepare dates for use in Excel or Database
         csv_cell = csv_cell.replace("T", " ").replace("Z", "")
     elif csv_column == 'CVE_LIST':
-        csv_cell = kb_format_cve_list(csv_cell, qid)
+        if present_csv_cell_as_json:
+            discarded_data = kb_update_cve_qid_list(csv_cell, qid)
+            csv_cell = json.dumps(csv_cell)
+        else:
+            csv_cell = kb_update_cve_qid_list(csv_cell, qid)
     elif not isinstance(csv_cell, str):  # Flatten Nested XML into String
-        flatten = etld_lib_functions.flatten_nest(csv_cell)
-        csv_cell = ""
-        for key in flatten.keys():
-            csv_cell = f"{csv_cell}{key}:{flatten[key]}\n"
+        if present_csv_cell_as_json:
+            csv_cell = json.dumps(csv_cell)
+        else:
+            flatten = etld_lib_functions.flatten_nest(csv_cell)
+            csv_cell = ""
+            for key in flatten.keys():
+                csv_cell = f"{csv_cell}{key}:{flatten[key]}\n"
 
     return csv_cell
 
@@ -28,6 +37,11 @@ def kb_create_csv_from_shelve(no_truncation=False):
     global kb_cve_qid_list
     global count_qids_written_to_shelve
     count_qids_written_to_shelve = 0
+    counter_obj = \
+        etld_lib_functions.DisplayCounterToLog(display_counter_at=10000,
+                                               logger_func=etld_lib_functions.logger.info,
+                                               display_counter_log_message=
+                                               "count knowledgebase records written to csv")
     kb_cve_qid_list = {}
     kb_csv_file = str(etld_lib_config.kb_csv_file)
 
@@ -47,7 +61,8 @@ def kb_create_csv_from_shelve(no_truncation=False):
                     truncated_field_list = "" # Column Name, Length
                     for csv_column in csv_columns:
                         if csv_column in kb_item.keys():
-                            kb_item[csv_column] = prepare_csv_cell(kb_item[csv_column], csv_column, kb_item['QID'])
+                            kb_item[csv_column] = prepare_csv_cell(kb_item[csv_column], csv_column, kb_item['QID'],
+                                                                   etld_lib_config.kb_present_csv_cell_as_json)
                             csv_record[csv_column] = kb_item[csv_column]
                             csv_record[csv_column], truncated_field_list = \
                                 etld_lib_functions.truncate_csv_cell(
@@ -64,8 +79,9 @@ def kb_create_csv_from_shelve(no_truncation=False):
 
                     writer.writerow(csv_record)
                     count_qids_written_to_shelve = count_qids_written_to_shelve + 1
+                    counter_obj.display_counter_to_log()
                     csv_record = csv_headers.copy()
-
+        counter_obj.display_final_counter_to_log()
     except Exception as e:
         etld_lib_functions.logger.error(f"Error in File: {__file__} Line: {etld_lib_functions.lineno()}")
         etld_lib_functions.logger.error(f"Error writing to file: {str(kb_csv_file)}, please retry after fixing error")
@@ -96,7 +112,7 @@ def kb_create_cve_qid_shelve():
         exit(1)
 
 
-def kb_format_cve_list(kb_item, qid):
+def kb_update_cve_qid_list(kb_item, qid):
     global kb_cve_qid_list
     kb_cve_list_return = ""
     if 'CVE' in kb_item.keys():
