@@ -27,6 +27,8 @@ global qetl_user_config_settings_yaml_file
 global qetl_user_config_settings_yaml
 global etld_lib_config_settings_yaml_dict
 global qetl_manage_user_selected_datetime
+# Requests Module SSL Verify Status
+global requests_module_tls_verify_status
 # USER KNOWLEDGEBASE
 global kb_data_dir
 global kb_bin_dir
@@ -45,6 +47,7 @@ global kb_log_rotate_file
 global kb_table_name
 global kb_csv_truncate_cell_limit
 global kb_data_files
+global kb_present_csv_cell_as_json
 # USER HOST LIST
 global host_list_data_dir
 global host_list_export_dir
@@ -66,6 +69,7 @@ global host_list_log_rotate_file
 global host_list_table_name
 global host_list_csv_truncate_cell_limit
 global host_list_data_files
+global host_list_present_csv_cell_as_json
 # USER HOST LIST DETECTION
 global host_list_detection_data_dir
 global host_list_detection_export_dir
@@ -86,6 +90,7 @@ global host_list_detection_multi_proc_batch_size
 global host_list_detection_limit_hosts
 global host_list_detection_table_name
 global host_list_detection_data_files
+global host_list_detection_present_csv_cell_as_json
 
 # USER ASSET INVENTORY
 global asset_inventory_data_dir
@@ -367,6 +372,7 @@ def get_kb_user_config():
     global kb_last_modified_after
     global qetl_user_config_settings_yaml_file
     global kb_csv_truncate_cell_limit
+    global kb_present_csv_cell_as_json
 
     kb_export_dir = etld_lib_config_settings_yaml_dict.get('kb_export_dir')
     kb_last_modified_after = etld_lib_config_settings_yaml_dict.get('kb_last_modified_after')
@@ -392,6 +398,11 @@ def get_kb_user_config():
     else:
         etld_lib_functions.logger.info(f"kb_last_modified_after yaml - {kb_last_modified_after}")
 
+    if 'kb_present_csv_cell_as_json' in etld_lib_config_settings_yaml_dict:
+        kb_present_csv_cell_as_json = etld_lib_config_settings_yaml_dict.get('kb_present_csv_cell_as_json')
+    else:
+        kb_present_csv_cell_as_json = False
+
 
 def setup_kb_vars():
     global qetl_user_data_dir
@@ -437,6 +448,7 @@ def get_host_list_user_config():
     global qetl_manage_user_selected_datetime
     global host_list_csv_truncate_cell_limit
     global host_list_sqlite_file
+    global host_list_present_csv_cell_as_json
 
     host_list_export_dir = etld_lib_config_settings_yaml_dict.get('host_list_export_dir')
     host_list_data_dir = qetl_user_data_dir
@@ -459,6 +471,11 @@ def get_host_list_user_config():
         etld_lib_functions.logger.error(f"host_list_csv_truncate_cell_limit file: {qetl_user_config_settings_yaml_file}")
         exit(1)
 
+    if 'host_list_present_csv_cell_as_json' in etld_lib_config_settings_yaml_dict:
+        host_list_present_csv_cell_as_json = etld_lib_config_settings_yaml_dict.get('host_list_present_csv_cell_as_json')
+    else:
+        host_list_present_csv_cell_as_json = False
+
     if qetl_manage_user_selected_datetime is not None:
         host_list_vm_processed_after = qetl_manage_user_selected_datetime
         etld_lib_functions.logger.info(f"host_list_vm_processed_after set by qetl_manage_user -d option - "
@@ -468,7 +485,7 @@ def get_host_list_user_config():
         #  use max_date to execute from that date.
         (min_date, max_date) = etld_lib_sqlite_tables.get_q_table_min_max_dates(
             host_list_sqlite_file, "LAST_VULN_SCAN_DATETIME", "Q_Host_List")
-        if max_date.startswith("20"):
+        if str(max_date).startswith("20"):
             etld_lib_functions.logger.info(f"Found Q_Host_List Min Date: {min_date} Max Date: {max_date}")
             max_date = re.sub(":..$", ":00", max_date)
             max_date = re.sub(" ", "T",max_date)
@@ -538,6 +555,7 @@ def get_host_list_detection_user_config():
     global qetl_user_config_settings_yaml_file
     global qetl_manage_user_selected_datetime
     global host_list_vm_processed_after
+    global host_list_detection_present_csv_cell_as_json
 
     host_list_detection_export_dir = etld_lib_config_settings_yaml_dict.get('host_list_detection_export_dir')
     host_list_detection_csv_truncate_cell_limit = \
@@ -559,6 +577,12 @@ def get_host_list_detection_user_config():
     host_list_detection_limit_hosts = \
         etld_lib_config_settings_yaml_dict.get('host_list_detection_limit_hosts')
 
+    if 'host_list_detection_present_csv_cell_as_json' in etld_lib_config_settings_yaml_dict:
+        host_list_detection_present_csv_cell_as_json = \
+            etld_lib_config_settings_yaml_dict.get('host_list_detection_present_csv_cell_as_json')
+    else:
+        host_list_detection_present_csv_cell_as_json = False
+
     etld_lib_functions.logger.info(f"host list detection config - {qetl_user_config_settings_yaml_file}")
     etld_lib_functions.logger.info(f"host_list_detection_export_dir yaml - {host_list_detection_export_dir}")
     etld_lib_functions.logger.info(f"host_list_detection_concurrency_limit yaml - {host_list_detection_concurrency_limit}")
@@ -573,7 +597,7 @@ def get_host_list_detection_user_config():
     elif host_list_detection_vm_processed_after == 'default':
         (min_date, max_date) = etld_lib_sqlite_tables.get_q_table_min_max_dates(
             host_list_sqlite_file, "LAST_VULN_SCAN_DATETIME", "Q_Host_List")
-        if max_date.startswith("20"):
+        if str(max_date).startswith("20"):
             max_date = re.sub(":..$", ":00", max_date)
             max_date = re.sub(" ", "T", max_date)
             max_date = re.sub("$", "Z", max_date)
@@ -751,12 +775,35 @@ def get_qetl_code_dir():
     qetl_code_dir_child = etld_lib_functions.qetl_code_dir_child
 
 
+def setup_requests_module_tls_verify_status():
+    global requests_module_tls_verify_status
+    if 'requests_module_tls_verify_status' in etld_lib_config_settings_yaml_dict:
+        requests_module_tls_verify_status = etld_lib_config_settings_yaml_dict.get('requests_module_tls_verify_status')
+    else:
+        requests_module_tls_verify_status = True
+
+    if requests_module_tls_verify_status is True or requests_module_tls_verify_status is False:
+        pass
+    else:
+        requests_module_tls_verify_status = True
+        etld_lib_functions.logger.warn(f"requests_module_tls_verify_status defaulting to True")
+
+    if requests_module_tls_verify_status is False:
+        etld_lib_functions.logger.warn(f"requests_module_tls_verify_status in etld_config.yaml is set "
+                                       f"to: {requests_module_tls_verify_status} "
+                                       f"You have selected to not verify tls certificates, subjecting your application "
+                                       f"to man in the middle attacks.  Please repair your certificate issue and "
+                                       f"reset requests_module_tls_verify_status in etld_config.yaml to True. ")
+
+
 def main():
     get_qetl_code_dir()
     setup_user_home_directories()
 
     load_etld_lib_config_settings_yaml()
 
+    setup_requests_module_tls_verify_status()
+
     setup_kb_vars()
     get_kb_user_config()
 
