@@ -69,28 +69,30 @@ def remove_low_high_values(chunk):  # Remove utf-8 values other than utf-8 decim
     return chunk
 
 
-def flatten_dictionary(data):
-    def data_items():
-        if isinstance(data, list):
-            for key, value in enumerate(data):
-                if isinstance(value, dict) or isinstance(value, list):
-                    for subkey, subvalue in flatten_dictionary(value).items():
-                        yield str(key) + "." + subkey, subvalue
-                else:
-                    yield str(key), value
-        else:
-            for key, value in data.items():
-                if isinstance(value, dict) or isinstance(value, list):
-                    for subkey, subvalue in flatten_dictionary(value).items():
-                        yield key + "." + subkey, subvalue
-                else:
-                    yield key, value
-#
-    return dict(data_items())
+# def flatten_dictionary(data):
+#     def data_items():
+#         if isinstance(data, list):
+#             for key, value in enumerate(data):
+#                 if isinstance(value, dict) or isinstance(value, list):
+#                     for subkey, subvalue in flatten_dictionary(value).items():
+#                         yield str(key) + "." + subkey, subvalue
+#                 else:
+#                     yield str(key), value
+#         else:
+#             for key, value in data.items():
+#                 if isinstance(value, dict) or isinstance(value, list):
+#                     for subkey, subvalue in flatten_dictionary(value).items():
+#                         yield key + "." + subkey, subvalue
+#                 else:
+#                     yield key, value
+# #
+#     return dict(data_items())
 
 
 def truncate_csv_cell(max_length=32700, csv_cell="", truncated_field_list="", csv_column=""):
-    if len(csv_cell) > max_length:
+    if max_length == 0:
+        pass
+    elif len(csv_cell) > max_length:
         truncated_field_list = f"{truncated_field_list}{csv_column}:{len(csv_cell):,} truncated_at: {max_length:,}\n"
         csv_cell = csv_cell[:max_length]
 
@@ -216,7 +218,7 @@ def check_python_version():
 
 def get_file_size(path_to_file):
     if Path(path_to_file).is_file():
-       return Path(path_to_file).stat().st_size
+        return Path(path_to_file).stat().st_size
 
 
 def get_file_mtime(path_to_file):
@@ -427,6 +429,34 @@ def file_is_locked(test_lock_file=None):
         return True
 
 
+class DisplayCounterToLog:
+    def __init__(self, display_counter_at=10000, logger_func=None, display_counter_log_message="count"):
+        self.counter = 0
+        self.display_counter = 0
+        self.display_counter_at = display_counter_at
+        self.logger_func = logger_func
+        self.display_counter_log_message = display_counter_log_message
+
+    def update_counter(self):
+        self.counter += 1
+        self.display_counter += 1
+
+    def display_counter_to_log(self):
+        self.update_counter()
+        if self.display_counter >= self.display_counter_at:
+            self.display_counter = 0
+            if self.logger_func is None:
+                print(f"{self.display_counter_log_message}: {self.counter:,}")
+            else:
+                self.logger_func(f"{self.display_counter_log_message}: {self.counter:,}")
+
+    def display_final_counter_to_log(self):
+        if self.logger_func is None:
+            print(f"{self.display_counter_log_message} - Total: {self.counter:,}")
+        else:
+            self.logger_func(f"{self.display_counter_log_message} - Total: {self.counter:,}")
+
+
 def main(log_level=logging.INFO, my_logger_prog_name=None):
     global logging_level
     setup_logging_stdout(log_level, my_logger_prog_name)
