@@ -76,7 +76,7 @@ def spawn_etl_in_background():
     while spawned_process.is_alive():
         spawned_process_report_status()
 
-    spawned_process_gracefully_ended()
+    spawned_process_ended()
     time.sleep(1)
 
 
@@ -136,7 +136,7 @@ def spawned_process_report_status():
         spawned_process_status_update()
 
 
-def spawned_process_gracefully_ended():
+def spawned_process_ended():
     global spawned_process_stop_time
     spawned_process_stop_time = timeit.default_timer()
     run_time = (spawned_process_stop_time - spawned_process_start_time)
